package com.ruoyi.project.ehs.mapper;

import java.util.List;
import com.ruoyi.framework.aspectj.lang.annotation.DataScope;
import com.ruoyi.project.ehs.domain.TFirehydrant;

/**
 * 消防栓Mapper接口
 * 
 * @author ruoyi
 * @date 2020-11-25
 */
public interface TFirehydrantMapper 
{
    /**
     * 查询消防栓
     * 
     * @param id 消防栓ID
     * @return 消防栓
     */
    public TFirehydrant selectTFirehydrantById(Long id);

    /**
     * 查询消防栓列表
     * 
     * @param tFirehydrant 消防栓
     * @return 消防栓集合
     */
    @DataScope(deptAlias = "d")
    public List<TFirehydrant> selectTFirehydrantList(TFirehydrant tFirehydrant);

    /**
     * 定时任务查询消防栓列表
     *
     * @param tFirehydrant 消防栓
     * @return 消防栓集合
     */
    public List<TFirehydrant> selectList(TFirehydrant tFirehydrant);

    /**
     * 新增消防栓
     * 
     * @param tFirehydrant 消防栓
     * @return 结果
     */
    public int insertTFirehydrant(TFirehydrant tFirehydrant);

    /**
     * 修改消防栓
     * 
     * @param tFirehydrant 消防栓
     * @return 结果
     */
    public int updateTFirehydrant(TFirehydrant tFirehydrant);

    /**
     * 删除消防栓
     * 
     * @param id 消防栓ID
     * @return 结果
     */
    public int deleteTFirehydrantById(Long id);

    /**
     * 批量删除消防栓
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteTFirehydrantByIds(Long[] ids);
}
